@@ -3,7 +3,7 @@
 |''Description''|adaptor for interacting with TiddlyWeb|
 |''Author:''|FND|
 |''Contributors''|Chris Dent, Martin Budden|
-|''Version''|1.4.3|
+|''Version''|1.4.8|
 |''Status''|stable|
 |''Source''|http://svn.tiddlywiki.org/Trunk/association/adaptors/TiddlyWebAdaptor.js|
 |''CodeRepository''|http://svn.tiddlywiki.org/Trunk/association/|
@@ -237,7 +237,11 @@ adaptor.getTiddlerCallback = function(status, context, responseText, uri, xhr) {
 		var tiddler = adaptor.toTiddler(tid, context.host);
 		tiddler.title = context.tiddler.title;
 		tiddler.fields["server.etag"] = xhr.getResponseHeader("Etag");
-		context.tiddler = tiddler;
+		// normally we'd assign context.tiddler = tiddler here - but we can't do
+		// that because of IE, which triggers getTiddler in putTiddlerCallback,
+		// and since ServerSideSavingPlugin foolishly relies on persistent
+		// object references, we need to merge the data into the existing object
+		$.extend(context.tiddler, tiddler);
 	}
 	if(context.callback) {
 		context.callback(context, context.userParams);
@@ -310,12 +314,14 @@ adaptor.putTiddlerCallback = function(status, context, responseText, uri, xhr) {
 	context.statusText = xhr.statusText;
 	context.httpStatus = xhr.status;
 	if(context.status) {
-		var bag = xhr.getResponseHeader("Location").
-			split("/bags/").pop().split("/")[0];
-		context.tiddler.fields["server.bag"] = bag;
-		context.tiddler.fields["server.workspace"] = "bags/" + bag;
+		var loc = xhr.getResponseHeader("Location");
 		var etag = xhr.getResponseHeader("Etag");
-		if(etag) {
+		if(loc && etag) {
+			var bag = loc.split("/bags/").pop().split("/")[0];
+			context.tiddler.fields["server.bag"] = bag;
+			context.tiddler.fields["server.workspace"] = "bags/" + bag;
+			var rev = etag.split("/").pop().split(";")[0];
+			context.tiddler.fields["server.page.revision"] = rev;
 			context.tiddler.fields["server.etag"] = etag;
 			if(context.callback) {
 				context.callback(context, context.userParams);
@@ -408,12 +414,12 @@ adaptor.prototype.moveTiddler = function(from, to, context, userParams, callback
 		}
 		// add new revision
 		var rev = $.extend({}, revisions[0]);
-		rev.title = to.title;
 		$.each(newTiddler, function(i, item) {
 			if(!$.isFunction(item)) {
 				rev[i] = item;
 			}
 		});
+		rev.title = to.title;
 		rev.created = rev.created.convertToYYYYMMDDHHMM();
 		rev.modified = new Date().convertToYYYYMMDDHHMM();
 		delete rev.fields.changecount;
@@ -423,7 +429,10 @@ adaptor.prototype.moveTiddler = function(from, to, context, userParams, callback
 		} else if(context.workspace.substring(0, 4) != "bags") { // NB: target workspace must be a bag
 			context.workspace = "bags/" + rev.bag;
 		}
-		var subCallback = function(context, userparams) {
+		var subCallback = function(context, userParams) {
+			if(!context.status) {
+				return callback(context, userParams);
+			}
 			context.adaptor.getTiddler(newTiddler.title, context, userParams, _deleteTiddler);
 		};
 		return self.putTiddlerChronicle(revisions, context, context.userParams, subCallback);
